@@ -1,3 +1,4 @@
+import json
 import re
 from sly import Lexer
 
@@ -23,8 +24,10 @@ class MindsDBLexer(Lexer):
 
         # SHOW Keywords
 
-        SHOW, SCHEMAS, DATABASES, TABLES, TABLE, FULL, VARIABLES, SESSION, STATUS,
-        GLOBAL, PROCEDURE, FUNCTION, INDEX, WARNINGS, ENGINES, CHARSET, COLLATION, PLUGINS,
+        SHOW, SCHEMAS, DATABASES, TABLES, TABLE, FULL,
+        VARIABLES, SESSION, STATUS,
+        GLOBAL, PROCEDURE, FUNCTION, INDEX, WARNINGS,
+        ENGINES, CHARSET, COLLATION, PLUGINS, CHARACTER,
 
 
         # SELECT Keywords
@@ -38,7 +41,7 @@ class MindsDBLexer(Lexer):
         UNION, ALL,
 
         # Special
-        COMMA, LPAREN, RPAREN, PARAMETER,
+        DOT, COMMA, LPAREN, RPAREN, PARAMETER,
 
         # Operators
         PLUS, MINUS, DIVIDE, MODULO,
@@ -47,7 +50,11 @@ class MindsDBLexer(Lexer):
         IN, LIKE, CONCAT, BETWEEN, WINDOW,
 
         # Data types
-        CAST, ID, INTEGER, FLOAT, STRING, NULL, TRUE, FALSE}
+        CAST, ID, INTEGER, FLOAT, STRING, NULL, TRUE, FALSE,
+
+        JSON,
+
+    }
 
     RETRAIN = r'\bRETRAIN\b'
     # Custom commands
@@ -86,8 +93,8 @@ class MindsDBLexer(Lexer):
     ALTER = r'\bALTER\b'
 
     DESCRIBE = r'\bDESCRIBE\b'
-    # SHOW
 
+    # SHOW
     SHOW = r'\bSHOW\b'
     SCHEMAS = r'\bSCHEMAS\b'
     DATABASES = r'\bDATABASES\b'
@@ -105,6 +112,7 @@ class MindsDBLexer(Lexer):
     WARNINGS = r'\bWARNINGS\b'
     ENGINES = r'\bENGINES\b'
     CHARSET = r'\bCHARSET\b'
+    CHARACTER = r'\bCHARACTER\b'
     COLLATION = r'\bCOLLATION\b'
     PLUGINS = r'\bPLUGINS\b'
 
@@ -142,6 +150,7 @@ class MindsDBLexer(Lexer):
     ALL = r'\bALL\b'
 
     # Special
+    DOT = r'\.'
     COMMA = r','
     LPAREN = r'\('
     RPAREN = r'\)'
@@ -174,7 +183,7 @@ class MindsDBLexer(Lexer):
     TRUE = r'\bTRUE\b'
     FALSE = r'\bFALSE\b'
 
-    @_(r'([a-zA-Z_][a-zA-Z_0-9]*|`([^`]+)`)(\.([a-zA-Z_][a-zA-Z_.0-9]*|`([^`]+)`))*')
+    @_(r'(?:([a-zA-Z_$0-9]*[a-zA-Z_$]+[a-zA-Z_$0-9]*)|(?:`([^`]+)`))(?:\.(?:([a-zA-Z_$0-9]*[a-zA-Z_$]+[a-zA-Z_$0-9]*)|(?:`([^`]+)`)))*')
     def ID(self, t):
         return t
 
@@ -188,6 +197,11 @@ class MindsDBLexer(Lexer):
         t.value = int(t.value)
         return t
 
+    @_(r'\{[a-zA-Z0-9\"\':,\{\}\[\]\s]*\}')
+    def JSON(self, t):
+        t.value = json.loads(t.value)
+        return t
+
     @_(r'"[^"]*"',
        r"'[^']*'")
     def STRING(self, t):
